[−][src]Trait serde_query::DeserializeQuery
A data structure that can be deserialized with a query.
The Query type is a #[repr(transparent)] wrapper automatically generated by
the proc macro, and can be converted to the implementor
(the type with #[derive(DeserializeQuery)]) after deserializing from the document
using Deserialize implementation of the query type.
Associated Types
type Query
The query type.